@@ -37,7 +37,7 @@ require 'zlib'
 # == Issues with mechanize
 #
 # If you think you have a bug with mechanize, but aren't sure, please file a
-# ticket at https://github.com/tenderlove/mechanize/issues
+# ticket at https://github.com/sparklemotion/mechanize/issues
 #
 # Here are some common problems you may experience with mechanize
 #
@@ -73,7 +73,7 @@ class Mechanize
   ##
   # The version of Mechanize you are using.
 
-  VERSION = '2.3'
+  VERSION = '2.7.1'
 
   ##
   # Base mechanize error class
@@ -106,6 +106,8 @@ class Mechanize
   # * Windows IE 9
   # * Windows Mozilla
   # * iPhone (3.0)
+  # * iPad
+  # * Android (Motorola Xoom)
   #
   # Example:
   #
@@ -113,11 +115,11 @@ class Mechanize
   #   agent.user_agent_alias = 'Mac Safari'
 
   AGENT_ALIASES = {
-    'Mechanize' => "Mechanize/#{VERSION} Ruby/#{ruby_version} (http://github.com/tenderlove/mechanize/)",
+    'Mechanize' => "Mechanize/#{VERSION} Ruby/#{ruby_version} (http://github.com/sparklemotion/mechanize/)",
     'Linux Firefox' => 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.1) Gecko/20100122 firefox/3.6.1',
     'Linux Konqueror' => 'Mozilla/5.0 (compatible; Konqueror/3; Linux)',
     'Linux Mozilla' => 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4) Gecko/20030624',
-    'Mac FireFox' => 'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6',
+    'Mac Firefox' => 'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6',
     'Mac Mozilla' => 'Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.4a) Gecko/20030401',
     'Mac Safari 4' => 'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; de-at) AppleWebKit/531.21.8 (KHTML, like Gecko) Version/4.0.4 Safari/531.21.10',
     'Mac Safari' => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/534.51.22 (KHTML, like Gecko) Version/5.1.1 Safari/534.51.22',
@@ -127,14 +129,36 @@ class Mechanize
     'Windows IE 9' => 'Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0)',
     'Windows Mozilla' => 'Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.4b) Gecko/20030516 Mozilla Firebird/0.6',
     'iPhone' => 'Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420+ (KHTML, like Gecko) Version/3.0 Mobile/1C28 Safari/419.3',
+    'iPad' => 'Mozilla/5.0 (iPad; U; CPU OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B334b Safari/531.21.10',
+    'Android' => 'Mozilla/5.0 (Linux; U; Android 3.0; en-us; Xoom Build/HRI39) AppleWebKit/534.13 (KHTML, like Gecko) Version/4.0 Safari/534.13'
   }
 
+  AGENT_ALIASES['Mac FireFox'] = AGENT_ALIASES['Mac Firefox']
+  AGENT_ALIASES['Linux FireFox'] = AGENT_ALIASES['Linux Firefox']
+
   def self.inherited(child) # :nodoc:
-    child.html_parser ||= html_parser
-    child.log ||= log
+    child.html_parser = html_parser
+    child.log = log
     super
   end
 
+  ##
+  # Creates a new Mechanize instance and yields it to the given block.
+  #
+  # After the block executes, the instance is cleaned up. This includes
+  # closing all open connections.
+  #
+  #   Mechanize.start do |m|
+  #     m.get("http://example.com")
+  #   end
+
+  def self.start
+    instance = new
+    yield(instance)
+  ensure
+    instance.shutdown
+  end
+
   ##
   # Creates a new mechanize instance.  If a block is given, the created
   # instance is yielded to the block for setting up pre-connection state such
@@ -209,7 +233,7 @@ class Mechanize
   ##
   # Maximum number of items allowed in the history.  The default setting is 50
   # pages.  Note that the size of the history multiplied by the maximum
-  # response body size 
+  # response body size
 
   def max_history
     @agent.history.max_size
@@ -263,16 +287,16 @@ class Mechanize
   attr_accessor :history_added
 
   ##
-  # A list of hooks to call after retrieving a response.  Hooks are called with
-  # the agent and the response returned.
+  # A list of hooks to call after retrieving a response. Hooks are called with
+  # the agent, the URI, the response, and the response body.
 
   def post_connect_hooks
     @agent.post_connect_hooks
   end
 
   ##
-  # A list of hooks to call before making a request.  Hooks are called with
-  # the agent and the request to be performed.
+  # A list of hooks to call before retrieving a response. Hooks are called
+  # with the agent, the URI, the response, and the response body.
 
   def pre_connect_hooks
     @agent.pre_connect_hooks
@@ -443,7 +467,7 @@ class Mechanize
   #   agent.post('http://example.com/', "<message>hello</message>",
   #              'Content-Type' => 'application/xml')
 
-  def post(uri, query={}, headers={})
+  def post(uri, query = {}, headers = {})
     return request_with_entity(:post, uri, query, headers) if String === query
 
     node = {}
@@ -507,7 +531,7 @@ class Mechanize
   #
   #   agent.submit(page.forms.first, page.forms.first.buttons.first)
 
-  def submit(form, button=nil, headers={})
+  def submit(form, button = nil, headers = {})
     form.add_button_to_query(button) if button
 
     case form.method.upcase
@@ -542,6 +566,7 @@ class Mechanize
   # keep-alives, compression, redirects and headers.
 
   @html_parser = Nokogiri::HTML
+  @log = nil
 
   class << self
 
@@ -618,17 +643,42 @@ class Mechanize
   attr_reader :proxy_user
 
   ##
-  # Sets the user and password to be used for HTTP authentication.
-  # sets the optional domain for NTLM authentication
+  # *NOTE*: These credentials will be used as a default for any challenge
+  # exposing your password to disclosure to malicious servers.  Use of this
+  # method will warn.  This method is deprecated and will be removed in
+  # mechanize 3.
+  #
+  # Sets the +user+ and +password+ as the default credentials to be used for
+  # HTTP authentication for any server.  The +domain+ is used for NTLM
+  # authentication.
 
-  def auth(user, password, domain = nil)
-    @agent.user     = user
-    @agent.password = password
-    @agent.domain = domain
+  def auth user, password, domain = nil
+    caller.first =~ /(.*?):(\d+).*?$/
+
+    warn <<-WARNING
+At #{$1} line #{$2}
+
+Use of #auth and #basic_auth are deprecated due to a security vulnerability.
+
+    WARNING
+
+    @agent.add_default_auth user, password, domain
   end
 
   alias basic_auth auth
 
+  ##
+  # Adds credentials +user+, +pass+ for +uri+.  If +realm+ is set the
+  # credentials are used only for that realm.  If +realm+ is not set the
+  # credentials become the default for any realm on that URI.
+  #
+  # +domain+ and +realm+ are exclusive as NTLM does not follow RFC 2617.  If
+  # +domain+ is given it is only used for NTLM authentication.
+
+  def add_auth uri, user, password, realm = nil, domain = nil
+    @agent.add_auth uri, user, password, realm, domain
+  end
+
   ##
   # Are If-Modified-Since conditional requests enabled?
 
@@ -727,6 +777,28 @@ class Mechanize
     @agent.idle_timeout = idle_timeout
   end
 
+  ##
+  # When set to true mechanize will ignore an EOF during chunked transfer
+  # encoding so long as at least one byte was received.  Be careful when
+  # enabling this as it may cause data loss.
+  #
+  # Net::HTTP does not inform mechanize of where in the chunked stream the EOF
+  # occurred.  Usually it is after the last-chunk but before the terminating
+  # CRLF (invalid termination) but it may occur earlier.  In the second case
+  # your response body may be incomplete.
+
+  def ignore_bad_chunking
+    @agent.ignore_bad_chunking
+  end
+
+  ##
+  # When set to true mechanize will ignore an EOF during chunked transfer
+  # encoding.  See ignore_bad_chunking for further details
+
+  def ignore_bad_chunking= ignore_bad_chunking
+    @agent.ignore_bad_chunking = ignore_bad_chunking
+  end
+
   ##
   # Are HTTP/1.1 keep-alive connections enabled?
 
@@ -837,6 +909,8 @@ class Mechanize
     @agent.redirect_ok = follow
   end
 
+  alias follow_redirect= redirect_ok=
+
   ##
   # Maximum number of redirections to follow
 
@@ -970,7 +1044,7 @@ class Mechanize
   # An OpenSSL client certificate or the path to a certificate file.
 
   def cert
-    @agent.cert
+    @agent.certificate
   end
 
   ##
@@ -1029,7 +1103,7 @@ class Mechanize
   # An OpenSSL private key or the path to a private key
 
   def key
-    @agent.key
+    @agent.private_key
   end
 
   ##
@@ -1160,6 +1234,22 @@ class Mechanize
     @agent.set_proxy address, port, user, password
   end
 
+  ##
+  # Clears history and cookies.
+
+  def reset
+    @agent.reset
+  end
+
+  ##
+  # Shuts down this session by clearing browsing state and closing all
+  # persistent connections.
+
+  def shutdown
+    reset
+    @agent.shutdown
+  end
+
   private
 
   ##
@@ -1194,6 +1284,8 @@ class Mechanize
 
 end
 
+require 'mechanize/response_read_error'
+require 'mechanize/chunked_termination_error'
 require 'mechanize/content_type_error'
 require 'mechanize/cookie'
 require 'mechanize/cookie_jar'
@@ -1219,9 +1311,8 @@ require 'mechanize/pluggable_parsers'
 require 'mechanize/redirect_limit_reached_error'
 require 'mechanize/redirect_not_get_or_head_error'
 require 'mechanize/response_code_error'
-require 'mechanize/unauthorized_error'
-require 'mechanize/response_read_error'
 require 'mechanize/robots_disallowed_error'
+require 'mechanize/unauthorized_error'
 require 'mechanize/unsupported_scheme_error'
 require 'mechanize/util'
 
