@@ -54,21 +54,30 @@ module Mechanize::Parser
   attr_accessor :code
 
   ##
-  # :method: [](header)
+  # :method: []
+  #
+  # :call-seq:
+  #   [](header)
   #
   # Access HTTP +header+ by name
 
   def_delegator :header, :[], :[]
 
   ##
-  # :method: []=(header, value)
+  # :method: []=
+  #
+  # :call-seq:
+  #   []=(header, value)
   #
   # Set HTTP +header+ to +value+
 
   def_delegator :header, :[]=, :[]=
 
   ##
-  # :method: key?(header)
+  # :method: key?
+  #
+  # :call-seq:
+  #   key?(header)
   #
   # Is the named +header+ present?
 
@@ -157,12 +166,12 @@ module Mechanize::Parser
   # Finds a free filename based on +filename+, but is not race-free
 
   def find_free_name filename
-    filename = @filename unless filename
+    base_filename = filename ||= @filename
 
     number = 1
 
     while File.exist? filename do
-      filename = "#{@filename}.#{number}"
+      filename = "#{base_filename}.#{number}"
       number += 1
     end
 
